/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: FieldAnnotationMetadata.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.metadata;

import org.ow2.easybeans.deployment.annotations.JField;

/**
 * This class represents the annotation metadata of a field.
 * @author Florent Benoit
 */
public class FieldAnnotationMetadata extends CommonAnnotationMetadata  {

    /**
     * Logger.
     */
    //private static Log logger = LogFactory.getLog(FieldAnnotationMetadata.class);

    /**
     * Method on which we got metadata.
     */
    private JField jField = null;

    /**
     * Parent metadata.
     */
    private ClassAnnotationMetadata classAnnotationMetadata = null;

    /**
     * This field is a field from a super class ?<br>
     */
    private boolean inherited = false;


    /**
     * Constructor.
     * @param jField the field on which we will set/add metadata
     * @param classAnnotationMetadata the parent metadata.
     */
    public FieldAnnotationMetadata(final JField jField, final ClassAnnotationMetadata classAnnotationMetadata) {
        this.jField = jField;
        this.classAnnotationMetadata = classAnnotationMetadata;
    }

    /**
     * @return name of the field
     */
    public String getFieldName() {
        return this.jField.getName();
    }

    /**
     * @return JMethod object
     */
    public JField getJField() {
        return this.jField;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        String titleIndent = " ";
        String indent = "   ";
        // classname
        sb.append(titleIndent);
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        sb.append("[\n");

        // Add super class toString()
        sb.append(super.toString());

        // Field
        sb.append(indent);
        sb.append("jField=");
        sb.append(jField);
        sb.append("\n");

        // inherited
        if (inherited) {
            sb.append(indent);
            sb.append("inherited=");
            sb.append(inherited);
            sb.append("\n");
        }


        sb.append(titleIndent);
        sb.append("]\n");
        return sb.toString();
    }



    /**
     * @return true if this method is inherited from a super class
     */
    public boolean isInherited() {
        return inherited;
    }

    /**
     * Sets the inheritance of this method.
     * @param inherited true if method is from a super class
     */
    public void setInherited(final boolean inherited) {
        this.inherited = inherited;
    }

    /**
     * @return parent metadata (class)
     */
    public ClassAnnotationMetadata getClassAnnotationMetadata() {
        return classAnnotationMetadata;
    }





}
